import json
import csv
import matplotlib.pyplot as plt


def main ():

    #EXAMPLE FROM RECTANGLE LIBRARY

    #load library file using the standard JSON python library
    rectLibrary = None
    with open("rectangle_5m_v1.0.json",'r') as libraryFile:
        rectLibrary = json.load(libraryFile)

    #defining m and n values (remember that n<m)
    n = 15
    m = 8

    #making key
    key1 = "{m:d}_{n:d}".format(m=m,n=n)

    #getting specific configuration from the library
    configuration = rectLibrary[key1]

    #Getting values of configuration
    gVals = configuration["g"]
    lntVals = configuration["logtime"]
    boreHoleLocations = configuration["bore_locations"]

    #Graphing Bore Hole Locations

    #Separating the points into x and y coordinates
    boreHoleX = [boreHoleLocation[0] for boreHoleLocation in boreHoleLocations]
    boreHoleY = [boreHoleLocation[1] for boreHoleLocation in boreHoleLocations]

    #Setting title for Graphs and csv file
    title = "Rectangular {n:d}X{m:d} Field".format(n=n,m=m)

    #plot the bore hole locations
    plt.scatter(boreHoleX,boreHoleY)
    plt.title( title)
    plt.gca().set_aspect('equal', adjustable='box')
    plt.xlabel("Distance (m)")
    plt.ylabel("Distance (m)")
    plt.show()

    #Getting a Specific G-Function for the configuration
    B = 5
    H=96
    rb = .075
    gFunc = gVals["{B:d}._{H:d}._{r:.3f}".format(B=B,H=H,r=rb)]

    #Graphing G-Function
    plt.clf()
    plt.title( title + " G-Function for H = {H:d}m".format(H=H))
    plt.xlabel("ln(t/ts)")
    plt.ylabel("g")
    plt.plot(lntVals,gFunc)
    plt.show()

    #Saving the G-Function to file
    with open( title + ".csv","w",newline="") as outputFile:
        cW = csv.writer(outputFile)
        cW.writerow(["ln(t/ts)","g"])
        for i in range(len(lntVals)):
            cW.writerow([lntVals[i],gFunc[i]])





    # Zoned Rectangle EXAMPLE

    # This is example is to help demonstrate how to use the libraries that require tow keys to access a configuration

    # load library file using the standard JSON python library
    Library = None
    with open("zoned_rectangle_5m_v1.0.json", 'r') as libraryFile:
       Library = json.load(libraryFile)

    # defining m and n values (remember that n<m)
    n = 17
    m = 13
    mi = 6
    ni = 8

    # making keys (there are two for this library)
    key1 = "{m:d}_{n:d}".format(m=m,n=n)

    # This second key will very based on the library being accessed (check the library overview document for more information)
    key2 = "{mi:d}_{ni:d}".format(mi=mi,ni=ni)

    # getting specific configuration from the library
    configuration = Library[key1][key2]

    # Getting values of configuration
    gVals = configuration["g"]
    lntVals = configuration["logtime"]
    boreHoleLocations = configuration["bore_locations"]

    # Graphing Bore Hole Locations

    # Separating the points into x and y coordinates
    boreHoleX = [boreHoleLocation[0] for boreHoleLocation in boreHoleLocations]
    boreHoleY = [boreHoleLocation[1] for boreHoleLocation in boreHoleLocations]

    # Setting title for Graphs and csv file
    title = "Zoned Rectangle {n:d}X{m:d} {ni:d}X{mi:d} Field".format(n=n, m=m, ni=ni,mi=mi)

    # plot the bore hole locations
    plt.scatter(boreHoleX, boreHoleY)
    plt.title(title)
    plt.gca().set_aspect('equal', adjustable='box')
    plt.xlabel("Distance (m)")
    plt.ylabel("Distance (m)")
    plt.show()

    # Getting a Specific G-Function for the configuration
    B = 5
    H = 384
    r = .0875
    gFunc = gVals["{B:d}._{H:d}._{r:.4f}".format(B=B, H=H, r=r)]

    # Graphing G-Function
    plt.clf()
    plt.title( title + " G-Function for H = {H:d}m".format(H=H))
    plt.xlabel("ln(t/ts)")
    plt.ylabel("g")
    plt.plot(lntVals, gFunc)
    plt.show()

    # Saving the G-Function to file
    with open( title + ".csv","w",newline="") as outputFile:
        cW = csv.writer(outputFile)
        cW.writerow(["ln(t/ts)", "g"])
        for i in range(len(lntVals)):
            cW.writerow([lntVals[i], gFunc[i]])






    # Open Rectangle EXAMPLE

    # This is example is to help demonstrate how to use the libraries that require tow keys to access a configuration

    # load library file using the standard JSON python library
    Library = None
    with open("Open_configurations_5m_v1.0.json", 'r') as libraryFile:
        Library = json.load(libraryFile)

    # defining m and n values (remember that n<m)
    n = 20
    m = 8
    t = 1

    # making keys (there are two for this library)
    key1 = "{m:d}_{n:d}".format(m=m,n=n)

    # This second key will very based on the library being accessed (check the library overview document for more information)
    key2 = "{t:d}".format(t=t)

    # getting specific configuration from the library
    configuration = Library[key1][key2]

    # Getting values of configuration
    gVals = configuration["g"]
    lntVals = configuration["logtime"]
    boreHoleLocations = configuration["bore_locations"]

    # Graphing Bore Hole Locations

    # Separating the points into x and y coordinates
    boreHoleX = [boreHoleLocation[0] for boreHoleLocation in boreHoleLocations]
    boreHoleY = [boreHoleLocation[1] for boreHoleLocation in boreHoleLocations]

    # Setting title for Graphs and csv file
    title =  "Open (Rectangle) {n:d}X{m:d} Field that is  {t:d} Thick".format(n=n, m=m, t=t)

    # plot the bore hole locations
    plt.scatter(boreHoleX, boreHoleY)
    plt.title(title)
    plt.gca().set_aspect('equal', adjustable='box')
    plt.xlabel("Distance (m)")
    plt.ylabel("Distance (m)")
    plt.show()

    # Getting a Specific G-Function for the configuration
    B = 5
    H = 192
    r = .08
    gFunc = gVals["{B:d}._{H:d}._{r:.2f}".format(B=B, H=H, r=r)]

    # Graphing G-Function
    plt.clf()
    plt.title( title + " G-Function for H = {H:d}m".format(H=H))
    plt.xlabel("ln(t/ts)")
    plt.ylabel("g")
    plt.plot(lntVals, gFunc)
    plt.show()

    # Saving the G-Function to file
    with open( title + ".csv","w",newline="") as outputFile:
        cW = csv.writer(outputFile)
        cW.writerow(["ln(t/ts)", "g"])
        for i in range(len(lntVals)):
            cW.writerow([lntVals[i], gFunc[i]])







    # C EXAMPLE

    # This is example is to help demonstrate how to use the libraries that require tow keys to access a configuration

    # load library file using the standard JSON python library
    Library = None
    with open("C_configurations_5m_v1.0.json", 'r') as libraryFile:
        Library = json.load(libraryFile)

    # defining m and n values (remember that n<m)
    n = 25
    m = 13
    t = 3

    # making keys (there are two for this library)
    key1 = "{m:d}_{n:d}".format(m=m,n=n)

    # This second key will very based on the library being accessed (check the library overview document for more information)
    key2 = "{t:d}".format(t=t)

    # getting specific configuration from the library
    configuration = Library[key1][key2]

    # Getting values of configuration
    gVals = configuration["g"]
    lntVals = configuration["logtime"]
    boreHoleLocations = configuration["bore_locations"]

    # Graphing Bore Hole Locations

    # Separating the points into x and y coordinates
    boreHoleX = [boreHoleLocation[0] for boreHoleLocation in boreHoleLocations]
    boreHoleY = [boreHoleLocation[1] for boreHoleLocation in boreHoleLocations]

    # Setting title for Graphs and csv file
    title =  "C {n:d}X{m:d} Field with {t:d} Removed".format(n=n, m=m, t=t)

    # plot the bore hole locations
    plt.scatter(boreHoleX, boreHoleY)
    plt.title(title)
    plt.gca().set_aspect('equal', adjustable='box')
    plt.xlabel("Distance (m)")
    plt.ylabel("Distance (m)")
    plt.show()

    # Getting a Specific G-Function for the configuration
    B = 5
    H = 48
    r = .075
    gFunc = gVals["{B:d}._{H:d}._{r:.3f}".format(B=B, H=H, r=r)]

    # Graphing G-Function
    plt.clf()
    plt.title( title + " G-Function for H = {H:d}m".format(H=H))
    plt.xlabel("ln(t/ts)")
    plt.ylabel("g")
    plt.plot(lntVals, gFunc)
    plt.show()

    # Saving the G-Function to file
    with open( title + ".csv","w",newline="") as outputFile:
        cW = csv.writer(outputFile)
        cW.writerow(["ln(t/ts)", "g"])
        for i in range(len(lntVals)):
            cW.writerow([lntVals[i], gFunc[i]])






    # L EXAMPLE

    # This is example is to help demonstrate how to use the libraries that require tow keys to access a configuration

    # load library file using the standard JSON python library
    Library = None
    with open("L_configurations_5m_v1.0.json", 'r') as libraryFile:
        Library = json.load(libraryFile)

    # defining m and n values (remember that n<m)
    n = 28
    m = 28

    # making keys (there is only one for this library)
    key1 = "{m:d}_{n:d}".format(m=m,n=n)


    # getting specific configuration from the library
    configuration = Library[key1]

    # Getting values of configuration
    gVals = configuration["g"]
    lntVals = configuration["logtime"]
    boreHoleLocations = configuration["bore_locations"]

    # Graphing Bore Hole Locations

    # Separating the points into x and y coordinates
    boreHoleX = [boreHoleLocation[0] for boreHoleLocation in boreHoleLocations]
    boreHoleY = [boreHoleLocation[1] for boreHoleLocation in boreHoleLocations]

    # Setting title for Graphs and csv file
    title = "L {n:d}X{m:d} Field".format(n=n, m=m, r=r)

    # plot the bore hole locations
    plt.scatter(boreHoleX, boreHoleY)
    plt.title(title)
    plt.gca().set_aspect('equal', adjustable='box')
    plt.xlabel("Distance (m)")
    plt.ylabel("Distance (m)")
    plt.show()

    # Getting a Specific G-Function for the configuration
    B = 5
    H = 24
    r = .075
    gFunc = gVals["{B:d}._{H:d}._{r:.3f}".format(B=B, H=H, r=r)]

    # Graphing G-Function
    plt.clf()
    plt.title( title + " G-Function for H = {H:d}m".format(H=H))
    plt.xlabel("ln(t/ts)")
    plt.ylabel("g")
    plt.plot(lntVals, gFunc)
    plt.show()

    # Saving the G-Function to file
    with open( title + ".csv","w",newline="") as outputFile:
        cW = csv.writer(outputFile)
        cW.writerow(["ln(t/ts)", "g"])
        for i in range(len(lntVals)):
            cW.writerow([lntVals[i], gFunc[i]])





    #U EXAMPLE

    # This is example is to help demonstrate how to use the libraries that require tow keys to access a configuration

    # load library file using the standard JSON python library
    Library = None
    with open("U_configurations_5m_v1.0.json", 'r') as libraryFile:
        Library = json.load(libraryFile)

    # defining m and n values (remember that n<m)
    n = 24
    m = 15
    t = 2

    # making keys (there are two for this library)
    key1 = "{m:d}_{n:d}".format(m=m,n=n)

    # This second key will very based on the library being accessed (check the library overview document for more information)
    key2 = "{t:d}".format(t=t)

    # getting specific configuration from the library
    configuration = Library[key1][key2]

    # Getting values of configuration
    gVals = configuration["g"]
    lntVals = configuration["logtime"]
    boreHoleLocations = configuration["bore_locations"]

    # Graphing Bore Hole Locations

    # Separating the points into x and y coordinates
    boreHoleX = [boreHoleLocation[0] for boreHoleLocation in boreHoleLocations]
    boreHoleY = [boreHoleLocation[1] for boreHoleLocation in boreHoleLocations]

    # Setting title for Graphs and csv file
    title = "U {n:d}X{m:d} Field that is  {t:d} thick".format(n=n, m=m, t=t)

    # plot the bore hole locations
    plt.scatter(boreHoleX, boreHoleY)
    plt.title(title)
    plt.gca().set_aspect('equal', adjustable='box')
    plt.xlabel("Distance (m)")
    plt.ylabel("Distance (m)")
    plt.show()

    # Getting a Specific G-Function for the configuration
    B = 5
    H = 192
    r = .08
    gFunc = gVals["{B:d}._{H:d}._{r:.2f}".format(B=B, H=H, r=r)]

    # Graphing G-Function
    plt.clf()
    plt.title( title + " G-Function for H = {H:d}m".format(H=H))
    plt.xlabel("ln(t/ts)")
    plt.ylabel("g")
    plt.plot(lntVals, gFunc)
    plt.show()

    # Saving the G-Function to file
    with open( title + ".csv","w",newline="") as outputFile:
        cW = csv.writer(outputFile)
        cW.writerow(["ln(t/ts)", "g"])
        for i in range(len(lntVals)):
            cW.writerow([lntVals[i], gFunc[i]])









    # LopU EXAMPLE

    # This is example is to help demonstrate how to use the libraries that require tow keys to access a configuration

    # load library file using the standard JSON python library
    LopULibrary = None
    with open("LopU_configurations_5m_v1.0.json", 'r') as libraryFile:
        LopULibrary = json.load(libraryFile)

    # defining m and n values (remember that n<m)
    n = 24
    m = 15
    r = 5

    # making keys (there are two for this library)
    key1 = "{m:d}_{n:d}".format(m=m,n=n)

    # This second key will very based on the library being accessed (check the library overview document for more information)
    key2 = "{r:d}".format(r=r)

    # getting specific configuration from the library
    configuration = LopULibrary[key1][key2]

    # Getting values of configuration
    gVals = configuration["g"]
    lntVals = configuration["logtime"]
    boreHoleLocations = configuration["bore_locations"]

    # Graphing Bore Hole Locations

    # Separating the points into x and y coordinates
    boreHoleX = [boreHoleLocation[0] for boreHoleLocation in boreHoleLocations]
    boreHoleY = [boreHoleLocation[1] for boreHoleLocation in boreHoleLocations]

    # Setting title for Graphs and csv file
    title = "LopU {n:d}X{m:d} Field with {r:d} Removed".format(n=n, m=m, r=r)

    # plot the bore hole locations
    plt.scatter(boreHoleX, boreHoleY)
    plt.title(title)
    plt.gca().set_aspect('equal', adjustable='box')
    plt.xlabel("Distance (m)")
    plt.ylabel("Distance (m)")
    plt.show()

    # Getting a Specific G-Function for the configuration
    B = 5
    H = 192
    r = .08
    gFunc = gVals["{B:d}._{H:d}._{r:.2f}".format(B=B, H=H, r=r)]

    # Graphing G-Function
    plt.clf()
    plt.title( title + " G-Function for H = {H:d}m".format(H=H))
    plt.xlabel("ln(t/ts)")
    plt.ylabel("g")
    plt.plot(lntVals, gFunc)
    plt.show()

    # Saving the G-Function to file
    with open( title + ".csv","w",newline="") as outputFile:
        cW = csv.writer(outputFile)
        cW.writerow(["ln(t/ts)", "g"])
        for i in range(len(lntVals)):
            cW.writerow([lntVals[i], gFunc[i]])









if __name__ == "__main__":
    main()